@@ -234,7 +234,7 @@ class TrocketClient(AbstractClient):
 
 
     def DeleteInstance(self, request):
-        """删除实例
+        """删除 RocketMQ 5.x 集群。
 
         :param request: Request instance for DeleteInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DeleteInstanceRequest`
@@ -443,12 +443,35 @@ class TrocketClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeConsumerLag(self, request):
+        """查询指定消费组堆积数。
+
+        :param request: Request instance for DescribeConsumerLag.
+        :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerLagRequest`
+        :rtype: :class:`tencentcloud.trocket.v20230308.models.DescribeConsumerLagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeConsumerLag", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeConsumerLagResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeFusionInstanceList(self, request):
-        """获取实例列表，Filters参数使用说明如下：
+        """查询集群列表，支持 4.x 和 5.x 集群，其中 Filters 参数使用说明如下：
         1. InstanceName, 名称模糊查询
-        2. InstanceId，实例ID查询
-        3. InstanceType, 实例类型查询，支持多选
-        4. Version，实例版本查询
+        2. InstanceId，集群ID查询
+        3. InstanceType, 集群类型查询，支持多选
+        4. Version，集群版本查询
         当使用TagFilters查询时，Filters参数失效。
 
         :param request: Request instance for DescribeFusionInstanceList.
@@ -472,7 +495,7 @@ class TrocketClient(AbstractClient):
 
 
     def DescribeInstance(self, request):
-        """查询实例信息
+        """查询 RocketMQ 5.x 集群信息。
 
         :param request: Request instance for DescribeInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.DescribeInstanceRequest`
@@ -495,7 +518,7 @@ class TrocketClient(AbstractClient):
 
 
     def DescribeInstanceList(self, request):
-        """获取集群列表，仅支持 5.x 集群，Filters参数使用说明如下：
+        """查询集群列表，仅支持 5.x 集群。Filters参数使用说明如下：
         1. InstanceName, 名称模糊查询
         2. InstanceId，集群ID查询
         3. InstanceType, 集群类型查询，支持多选
@@ -979,7 +1002,7 @@ class TrocketClient(AbstractClient):
 
 
     def ModifyInstance(self, request):
-        """修改实例属性
+        """修改 RocketMQ 5.x 集群属性。
 
         :param request: Request instance for ModifyInstance.
         :type request: :class:`tencentcloud.trocket.v20230308.models.ModifyInstanceRequest`
