@@ -29,18 +29,12 @@ FAILEDOPERATION_CLASSNAMEDUPLICATE = 'FailedOperation.ClassNameDuplicate'
 # 操作失败：分类不存在。
 FAILEDOPERATION_CLASSNOFOUND = 'FailedOperation.ClassNoFound'
 
-# 存在冲突域名
-FAILEDOPERATION_CONFLICTDOMAINEXIST = 'FailedOperation.ConflictDomainExist'
-
 # 操作失败：不支持的封面类型。
 FAILEDOPERATION_COVERTYPE = 'FailedOperation.CoverType'
 
 # 操作失败：数据库操作失败。
 FAILEDOPERATION_DBERROR = 'FailedOperation.DBError'
 
-# 域名已经存在
-FAILEDOPERATION_DOMAINALREADYEXIST = 'FailedOperation.DomainAlreadyExist'
-
 # 域名部署中，不能变更配置。
 FAILEDOPERATION_DOMAINDEPLOYING = 'FailedOperation.DomainDeploying'
 
@@ -80,9 +74,6 @@ FAILEDOPERATION_UPLOADCOSFAIL = 'FailedOperation.UploadCosFail'
 # 用户已经停服。
 FAILEDOPERATION_USERSTATUSINAVLID = 'FailedOperation.UserStatusInavlid'
 
-# 泛域名与其他账号的泛域名存在嵌套
-FAILEDOPERATION_WILDCARDDOMAINNESTEDCREATE = 'FailedOperation.WildCardDomainNestedCreate'
-
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -275,9 +266,15 @@ INVALIDPARAMETERVALUE_ENDTIME = 'InvalidParameterValue.EndTime'
 # 参数错误：无效的结束时间。
 INVALIDPARAMETERVALUE_ENDTIMEOFFSET = 'InvalidParameterValue.EndTimeOffset'
 
+# 名字重复
+INVALIDPARAMETERVALUE_EXISTEDNAME = 'InvalidParameterValue.ExistedName'
+
 # 参数值错误：ExpireTime 格式错误。
 INVALIDPARAMETERVALUE_EXPIRETIME = 'InvalidParameterValue.ExpireTime'
 
+# ExpiredTime 错误。
+INVALIDPARAMETERVALUE_EXPIREDTIME = 'InvalidParameterValue.ExpiredTime'
+
 # 参数值错误：人脸重复。
 INVALIDPARAMETERVALUE_FACEDUPLICATE = 'InvalidParameterValue.FaceDuplicate'
 
@@ -347,12 +344,18 @@ INVALIDPARAMETERVALUE_IMAGEDECODEERROR = 'InvalidParameterValue.ImageDecodeError
 # 参数错误：图片水印模板。
 INVALIDPARAMETERVALUE_IMAGETEMPLATE = 'InvalidParameterValue.ImageTemplate'
 
+# Index 参数错误。
+INVALIDPARAMETERVALUE_INDEX = 'InvalidParameterValue.Index'
+
 # 参数值错误：Interval 无效。
 INVALIDPARAMETERVALUE_INTERVAL = 'InvalidParameterValue.Interval'
 
 # 参数错误：无效的操作类型。
 INVALIDPARAMETERVALUE_INVALIDOPERATIONTYPE = 'InvalidParameterValue.InvalidOperationType'
 
+# 参数值错误：错误固化参数。
+INVALIDPARAMETERVALUE_ISPERSISTENCE = 'InvalidParameterValue.IsPersistence'
+
 # Isps 参数错误。
 INVALIDPARAMETERVALUE_ISPS = 'InvalidParameterValue.Isps'
 
@@ -413,12 +416,21 @@ INVALIDPARAMETERVALUE_OPERATION = 'InvalidParameterValue.Operation'
 # 参数值错误：文件原存储类型异常。
 INVALIDPARAMETERVALUE_ORIGINALSTORAGECLASS = 'InvalidParameterValue.OriginalStorageClass'
 
+# 参数值错误：错误的输出媒体文件类型。
+INVALIDPARAMETERVALUE_OUTPUTMEDIATYPE = 'InvalidParameterValue.OutputMediaType'
+
 # 参数值错误：ParentId 无效。
 INVALIDPARAMETERVALUE_PARENTID = 'InvalidParameterValue.ParentId'
 
 # 参数值错误：人脸图片格式错误。
 INVALIDPARAMETERVALUE_PICFORMATERROR = 'InvalidParameterValue.PicFormatError'
 
+# 参数值错误：错误的精度参数。
+INVALIDPARAMETERVALUE_PRECISION = 'InvalidParameterValue.Precision'
+
+# 参数值错误：错误的 Procedure 。
+INVALIDPARAMETERVALUE_PROCEDURE = 'InvalidParameterValue.Procedure'
+
 # 任务流模板名无效。
 INVALIDPARAMETERVALUE_PROCEDURENAME = 'InvalidParameterValue.ProcedureName'
 
@@ -452,6 +464,15 @@ INVALIDPARAMETERVALUE_REVIEWCONFIDENCE = 'InvalidParameterValue.ReviewConfidence
 # 参数值错误：ReviewWallSwitch 参数取值非法。
 INVALIDPARAMETERVALUE_REVIEWWALLSWITCH = 'InvalidParameterValue.ReviewWallSwitch'
 
+# 相同 ID 的播单已经存在。
+INVALIDPARAMETERVALUE_ROUNDPLAYALREADYEXISTS = 'InvalidParameterValue.RoundPlayAlreadyExists'
+
+# RoundPlayId 参数错误。
+INVALIDPARAMETERVALUE_ROUNDPLAYID = 'InvalidParameterValue.RoundPlayId'
+
+# RoundPlaylist 参数长度错误。
+INVALIDPARAMETERVALUE_ROUNDPLAYLIST = 'InvalidParameterValue.RoundPlaylist'
+
 # 参数值错误：RowCount。
 INVALIDPARAMETERVALUE_ROWCOUNT = 'InvalidParameterValue.RowCount'
 
@@ -464,6 +485,12 @@ INVALIDPARAMETERVALUE_SAMPLERATE = 'InvalidParameterValue.SampleRate'
 # 参数值错误：SampleType。
 INVALIDPARAMETERVALUE_SAMPLETYPE = 'InvalidParameterValue.SampleType'
 
+# 参数错误：Scheme 无效。
+INVALIDPARAMETERVALUE_SCHEME = 'InvalidParameterValue.Scheme'
+
+# 域名没有开启 https。
+INVALIDPARAMETERVALUE_SCHEMECONFLICT = 'InvalidParameterValue.SchemeConflict'
+
 # 参数值错误：ScreenshotInterval 参数取值非法。
 INVALIDPARAMETERVALUE_SCREENSHOTINTERVAL = 'InvalidParameterValue.ScreenshotInterval'
 
@@ -578,6 +605,9 @@ INVALIDPARAMETERVALUE_TYPES = 'InvalidParameterValue.Types'
 # 去重识别码一天内重复，请求被去重。
 INVALIDPARAMETERVALUE_UNIQUEIDENTIFIER = 'InvalidParameterValue.UniqueIdentifier'
 
+# 域名不能被设置。
+INVALIDPARAMETERVALUE_UNSUPPORTDOMAIN = 'InvalidParameterValue.UnsupportDomain'
+
 # 参数值错误：文件不支持该解冻方式。
 INVALIDPARAMETERVALUE_UNSUPPORTEDRESTORETIER = 'InvalidParameterValue.UnsupportedRestoreTier'
 
@@ -626,6 +656,15 @@ LIMITEXCEEDED = 'LimitExceeded'
 # 超过限制值：新旧打点信息个数和超过限制值。
 LIMITEXCEEDED_KEYFRAMEDESCCOUNTREACHMAX = 'LimitExceeded.KeyFrameDescCountReachMax'
 
+# 播放列表长度太大。
+LIMITEXCEEDED_PLAYLIST = 'LimitExceeded.PlayList'
+
+# 超过播单总数限制。
+LIMITEXCEEDED_ROUNDPLAYS = 'LimitExceeded.RoundPlays'
+
+# 运行中的播单超过最大数量。
+LIMITEXCEEDED_RUNNINGROUNDPLAYS = 'LimitExceeded.RunningRoundPlays'
+
 # 超过限制值：新旧标签个数和超过限制值。
 LIMITEXCEEDED_TAGCOUNTREACHMAX = 'LimitExceeded.TagCountReachMax'
 
@@ -674,9 +713,6 @@ UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 # 域名解析验证失败
 UNAUTHORIZEDOPERATION_DOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.DomainRecordNotVerified'
 
-# 域名已被其他账号接入
-UNAUTHORIZEDOPERATION_HOSTOWNEDBYOTHERS = 'UnauthorizedOperation.HostOwnedByOthers'
-
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
